===================================
salt.returners.cassandra_cql_return
===================================

.. automodule:: salt.returners.cassandra_cql_return
    :members:
    :exclude-members: save_minions
